@@ -1,11 +1,11 @@
-# Copyright (c) 2009 Simplistix Ltd
+# Copyright (c) 2009-2010 Simplistix Ltd
 #
 # See license.txt for more details.
 from __future__ import with_statement
 
 import os
 
-from checker import command
+import execute
 from os.path import join
 
 def check(config_folder,daemon):
@@ -13,7 +13,7 @@ def check(config_folder,daemon):
     if not os.path.exists(inits):
         os.mkdir(inits)
     with open(join(inits,daemon),'wb') as f:
-        for row in command.execute(
+        for row in execute.simple(
             '/usr/sbin/update-rc.d -n -f %s remove'%daemon
             ).split('\n'):
             row = row.strip()
