@@ -1,11 +1,11 @@
-# Copyright (c) 2009-2010 Simplistix Ltd
+# Copyright (c) 2009-2012 Simplistix Ltd
 #
 # See license.txt for more details.
 
 from checker.checkers.buildout import check
 from mock import Mock
 from testfixtures import replace,compare
-from unittest import TestCase,TestSuite,makeSuite
+from unittest import TestCase
 
 class TestBuildout(TestCase):
 
@@ -17,8 +17,3 @@ class TestBuildout(TestCase):
         compare(m.call_args_list,[
                 (('bin|buildout -o -q',), {'cwd': 'y'}),
                 ])
-
-def test_suite():
-    return TestSuite((
-        makeSuite(TestBuildout),
-        ))
